@@ -5,19 +5,18 @@ from jaseci.api.interface import interface
 from jaseci.utils.id_list import id_list
 
 
-class master_api():
-    """Master APIs for creating nicknames for UUIDs and other long strings
-
-    """
+class master_api:
+    """Master APIs for creating nicknames for UUIDs and other long strings"""
 
     def __init__(self, head_master):
         self._caller = self
         self.head_master_id = head_master
         self.sub_master_ids = id_list(self)
 
-    @interface.private_api(cli_args=['name'])
-    def master_create(self, name: str, set_active: bool = True,
-                      other_fields: dict = {}):
+    @interface.private_api(cli_args=["name"])
+    def master_create(
+        self, name: str, set_active: bool = True, other_fields: dict = {}
+    ):
         """
         Create a master instance and return root node master object
 
@@ -25,19 +24,19 @@ class master_api():
         (i.e., Dango interface)
         """
         from jaseci.element.master import master
+
         new_m = master(h=self._h, name=name)
         return self.make_me_head_master_or_destroy(new_m)
 
-    @interface.private_api(cli_args=['name'])
-    def master_get(self, name: str, mode: str = 'default',
-                   detailed: bool = False):
+    @interface.private_api(cli_args=["name"])
+    def master_get(self, name: str, mode: str = "default", detailed: bool = False):
         """
         Return the content of the master with mode
         Valid modes: {default, }
         """
         mas = self.sub_master_ids.get_obj_by_name(name)
-        if(not mas):
-            return {'response': f"{name} not found"}
+        if not mas:
+            return {"response": f"{name} not found"}
         else:
             return mas.serialize(detailed=detailed)
 
@@ -51,17 +50,17 @@ class master_api():
             masts.append(i.serialize(detailed=detailed))
         return masts
 
-    @interface.private_api(cli_args=['name'])
+    @interface.private_api(cli_args=["name"])
     def master_active_set(self, name: str):
         """
         Sets the default master master should use
         NOTE: Specail handler included in general_interface_to_api
         """
         mas = self.sub_master_ids.get_obj_by_name(name)
-        if(not mas):
-            return {'response': f"{name} not found"}
+        if not mas:
+            return {"response": f"{name} not found"}
         self._caller = mas
-        return {'response': f'You are now {mas.name}'}
+        return {"response": f"You are now {mas.name}"}
 
     @interface.private_api()
     def master_active_unset(self):
@@ -69,7 +68,7 @@ class master_api():
         Unsets the default sentinel master should use
         """
         self._caller = self
-        return {'response': f'You are now {self.name}'}
+        return {"response": f"You are now {self.name}"}
 
     @interface.private_api()
     def master_active_get(self, detailed: bool = False):
@@ -85,15 +84,15 @@ class master_api():
         """
         return self.serialize(detailed=detailed)
 
-    @interface.private_api(cli_args=['name'])
+    @interface.private_api(cli_args=["name"])
     def master_delete(self, name: str):
         """
         Permanently delete master with given id
         """
-        if(not self.sub_master_ids.has_obj_by_name(name)):
-            return {'response': f"{name} not found"}
+        if not self.sub_master_ids.has_obj_by_name(name):
+            return {"response": f"{name} not found"}
         self.sub_master_ids.destroy_obj_by_name(name)
-        return {'response': f"{name} has been destroyed"}
+        return {"response": f"{name} has been destroyed"}
 
     def make_me_head_master_or_destroy(self, m):
         """
@@ -101,10 +100,10 @@ class master_api():
         """
         m.head_master_id = self.jid
         m.give_access(self)
-        if(self.sub_master_ids.has_obj_by_name(m.name)):
+        if self.sub_master_ids.has_obj_by_name(m.name):
             name = m.name
             m.destroy()
-            return {'response': f"{name} already exists"}
+            return {"response": f"{name} already exists"}
         m.save()
         self.sub_master_ids.add_obj(m)
         return m.serialize()
