@@ -5,14 +5,13 @@ from jaseci.api.interface import interface
 from jaseci.element.master import master
 
 
-class super_api():
-    """Super APIs for creating nicknames for UUIDs and other long strings
+class super_api:
+    """Super APIs for creating nicknames for UUIDs and other long strings"""
 
-    """
-
-    @interface.admin_api(cli_args=['name'])
-    def master_createsuper(self, name: str, set_active: bool = True,
-                           other_fields: dict = {}):
+    @interface.admin_api(cli_args=["name"])
+    def master_createsuper(
+        self, name: str, set_active: bool = True, other_fields: dict = {}
+    ):
         """
         Create a super instance and return root node super object
 
@@ -20,6 +19,7 @@ class super_api():
         (i.e., Dango interface)
         """
         from jaseci.element.super_master import super_master
+
         new_m = super_master(h=self._h, name=name)
         return self.make_me_head_master_or_destroy(new_m)
 
@@ -31,11 +31,11 @@ class super_api():
         NOTE: Abstract interface to be overridden
         """
 
-    @interface.admin_api(cli_args=['mast'])
+    @interface.admin_api(cli_args=["mast"])
     def master_become(self, mast: master):
         """
         Sets the default master master should use
         FIXME: _caller does not persist accross http request!!
         """
         self._caller = mast
-        return {'response': f'You are now {mast.name}'}
+        return {"response": f"You are now {mast.name}"}
