@@ -9,7 +9,7 @@ from jaseci.utils.utils import b64decode_str
 from jaseci.utils.id_list import id_list
 
 
-class walker_api():
+class walker_api:
     """
     Walker APIs
     """
@@ -17,17 +17,17 @@ class walker_api():
     def __init__(self):
         self.spawned_walker_ids = id_list(self)
 
-    @interface.public_api(cli_args=['wlk'])
-    def walker_summon(self, key: str, wlk: walker, nd: node,
-                      ctx: dict = {}, global_sync: bool = True):
+    @interface.public_api(cli_args=["wlk"])
+    def walker_summon(
+        self, key: str, wlk: walker, nd: node, ctx: dict = {}, global_sync: bool = True
+    ):
         """
         Public api for running walkers, namespace key must be provided
         along with the walker id and node id
         """
-        if(key not in wlk.namespace_keys().values()):
-            return self.bad_walk_response(
-                ['Not authorized to execute this walker'])
-        if(global_sync):  # Test needed
+        if key not in wlk.namespace_keys().values():
+            return self.bad_walk_response(["Not authorized to execute this walker"])
+        if global_sync:  # Test needed
             self.sync_walker_from_global_sent(wlk)
         walk = wlk.duplicate()
         walk.refresh()
@@ -36,54 +36,53 @@ class walker_api():
         walk.destroy()
         return res
 
-    @interface.private_api(cli_args=['code'])
-    def walker_register(self, snt: sentinel = None,
-                        code: str = '', encoded: bool = False):
+    @interface.private_api(cli_args=["code"])
+    def walker_register(
+        self, snt: sentinel = None, code: str = "", encoded: bool = False
+    ):
         """
         Create blank or code loaded walker and return object
         """
-        if (encoded):
+        if encoded:
             code = b64decode_str(code)
         walk = snt.register_walker(code)
-        if(walk):
+        if walk:
             self.extract_wlk_aliases(snt, walk)
             return walk.serialize()
         else:
-            return ['Walker not created, invalid code!']
+            return ["Walker not created, invalid code!"]
 
-    @interface.private_api(cli_args=['wlk'])
-    def walker_get(self, wlk: walker, mode: str = 'default',
-                   detailed: bool = False):
+    @interface.private_api(cli_args=["wlk"])
+    def walker_get(self, wlk: walker, mode: str = "default", detailed: bool = False):
         """
         Get a walker rendered with specific mode
         Valid modes: {default, code, ir, keys, }
         """
-        if(mode == 'code'):
+        if mode == "code":
             return wlk._jac_ast.get_text()
-        elif(mode == 'ir'):
+        elif mode == "ir":
             return wlk.ir_dict()
-        elif(mode == 'keys'):
+        elif mode == "keys":
             return wlk.namespace_keys()
         else:
             return wlk.serialize(detailed=detailed)
 
-    @interface.private_api(cli_args=['wlk'])
-    def walker_set(self, wlk: walker, code: str,
-                   mode: str = 'default'):
+    @interface.private_api(cli_args=["wlk"])
+    def walker_set(self, wlk: walker, code: str, mode: str = "default"):
         """
         Set code/ir for a walker
         Valid modes: {code, ir, }
         """
-        if(mode == 'code' or mode == 'default'):
+        if mode == "code" or mode == "default":
             wlk.register(code)
-        elif(mode == 'ir'):
+        elif mode == "ir":
             wlk.apply_ir(code)
         else:
-            return [f'Invalid mode to set {wlk}']
-        if(wlk.is_active):
-            return [f'{wlk} registered and active!']
+            return [f"Invalid mode to set {wlk}"]
+        if wlk.is_active:
+            return [f"{wlk} registered and active!"]
         else:
-            return [f'{wlk} code issues encountered!']
+            return [f"{wlk} code issues encountered!"]
 
     @interface.private_api()
     def walker_list(self, snt: sentinel = None, detailed: bool = False):
@@ -95,7 +94,7 @@ class walker_api():
             walks.append(i.serialize(detailed=detailed))
         return walks
 
-    @interface.private_api(cli_args=['wlk'])
+    @interface.private_api(cli_args=["wlk"])
     def walker_delete(self, wlk: walker, snt: sentinel = None):
         """
         Permanently delete walker with given id
@@ -103,34 +102,34 @@ class walker_api():
         self.remove_wlk_aliases(snt, wlk)
         wlkid = wlk.id
         snt.walker_ids.destroy_obj(wlk)
-        return [f'Walker {wlkid} successfully deleted']
+        return [f"Walker {wlkid} successfully deleted"]
 
-    @interface.private_api(cli_args=['name'])
+    @interface.private_api(cli_args=["name"])
     def walker_spawn_create(self, name: str, snt: sentinel = None):
         """
         Creates new instance of walker and returns new walker object
         """
         wlk = snt.spawn_walker(name, caller=self)
-        if(wlk):
-            if(self.spawned_walker_ids.has_obj_by_name(name)):
+        if wlk:
+            if self.spawned_walker_ids.has_obj_by_name(name):
                 self.spawned_walker_ids.destroy_obj_by_name(name)
             self.spawned_walker_ids.add_obj(wlk)
-            self.alias_register(f'spawned:walker:{name}', wlk.jid)
+            self.alias_register(f"spawned:walker:{name}", wlk.jid)
             return wlk.serialize()
         else:
-            return ['Walker not found!']
+            return ["Walker not found!"]
 
-    @interface.private_api(cli_args=['name'])
+    @interface.private_api(cli_args=["name"])
     def walker_spawn_delete(self, name: str):
         """
         Delete instance of walker
         """
-        if(self.spawned_walker_ids.has_obj_by_name(name)):
+        if self.spawned_walker_ids.has_obj_by_name(name):
             self.spawned_walker_ids.destroy_obj_by_name(name)
-            self.alias_delete(f'spawned:walker:{name}')
-            return [f'Walker {name} deteled!']
+            self.alias_delete(f"spawned:walker:{name}")
+            return [f"Walker {name} deteled!"]
         else:
-            return [f'Walker {name} not found!']
+            return [f"Walker {name} not found!"]
 
     @interface.private_api()
     def walker_spawn_list(self, detailed: bool = False):
@@ -142,42 +141,54 @@ class walker_api():
             walks.append(i.serialize(detailed=detailed))
         return walks
 
-    @interface.private_api(cli_args=['wlk'])
+    @interface.private_api(cli_args=["wlk"])
     def walker_prime(self, wlk: walker, nd: node = None, ctx: dict = {}):
         """
         Assigns walker to a graph node and primes walker for execution
         """
         wlk.prime(nd, prime_ctx=ctx)
-        return [f'Walker primed on node {nd.id}']
+        return [f"Walker primed on node {nd.id}"]
 
-    @interface.private_api(cli_args=['wlk'])
-    def walker_execute(self, wlk: walker, prime: node = None,
-                       ctx: dict = {}, profiling: bool = False):
+    @interface.private_api(cli_args=["wlk"])
+    def walker_execute(
+        self, wlk: walker, prime: node = None, ctx: dict = {}, profiling: bool = False
+    ):
         """
         Executes walker (assumes walker is primed)
         """
-        if(prime):
+        if prime:
             self.walker_prime(wlk=wlk, nd=prime, ctx=ctx)
         return wlk.run(profiling=profiling)
 
-    @interface.private_api(cli_args=['name'])
-    def walker_run(self, name: str, nd: node = None, ctx: dict = {},
-                   snt: sentinel = None, profiling: bool = False):
+    @interface.private_api(cli_args=["name"])
+    def walker_run(
+        self,
+        name: str,
+        nd: node = None,
+        ctx: dict = {},
+        snt: sentinel = None,
+        profiling: bool = False,
+    ):
         """
         Creates walker instance, primes walker on node, executes walker,
         reports results, and cleans up walker instance.
         """
         wlk = snt.spawn_walker(name, caller=self)
-        if(not wlk):
-            return self.bad_walk_response([f'Walker {name} not found!'])
-        res = self.walker_execute(
-            wlk=wlk, prime=nd, ctx=ctx, profiling=profiling)
+        if not wlk:
+            return self.bad_walk_response([f"Walker {name} not found!"])
+        res = self.walker_execute(wlk=wlk, prime=nd, ctx=ctx, profiling=profiling)
         wlk.destroy()
         return res
 
-    @interface.private_api(cli_args=['name'], url_args=['name'])
-    def wapi(self, name: str, nd: node = None, ctx: dict = {},
-             snt: sentinel = None, profiling: bool = False):
+    @interface.private_api(cli_args=["name"], url_args=["name"])
+    def wapi(
+        self,
+        name: str,
+        nd: node = None,
+        ctx: dict = {},
+        snt: sentinel = None,
+        profiling: bool = False,
+    ):
         """
         Walker individual APIs
         """
@@ -191,4 +202,4 @@ class walker_api():
             i.destroy()
 
     def bad_walk_response(self, errors=list()):
-        return {'report': [], 'success': False, 'errors': errors}
+        return {"report": [], "success": False, "errors": errors}
