@@ -11,10 +11,10 @@ class jac_json_enc(json.JSONEncoder):
     """Custom Json encoder for Jac ASTs"""
 
     def default(self, obj):
-        if(isinstance(obj, ast)):
+        if isinstance(obj, ast):
             retd = {}
             for i in obj.__dict__.keys():
-                if(not i.startswith('_')):
+                if not i.startswith("_"):
                     retd[i] = obj.__dict__[i]
             return retd
         return super().default(obj)
@@ -24,13 +24,12 @@ class jac_json_dec(json.JSONDecoder):
     """Custom hook for decoding Jac ASTs"""
 
     def __init__(self, *args, **kwargs):
-        json.JSONDecoder.__init__(
-            self, object_hook=self.object_hook, *args, **kwargs)
+        json.JSONDecoder.__init__(self, object_hook=self.object_hook, *args, **kwargs)
 
     def object_hook(self, obj):
 
         if isinstance(obj, dict) and "mod_name" in obj and "kid" in obj:
-            ret = ast(mod_name=obj['mod_name'], fresh_start=False)
+            ret = ast(mod_name=obj["mod_name"], fresh_start=False)
             for i in obj.keys():
                 setattr(ret, i, obj[i])
             return ret
@@ -47,7 +46,7 @@ def jac_ir_to_ast(ir):
     return json.loads(cls=jac_json_dec, s=ir)
 
 
-class jac_code():
+class jac_code:
     """Obj mixin to code pickling"""
 
     def __init__(self, code_ir=None):
@@ -63,25 +62,25 @@ class jac_code():
 
     def refresh(self):
         self._jac_ast = jac_ir_to_ast(self.code_ir) if self.code_ir else None
-        if(self._jac_ast):
+        if self._jac_ast:
             self.is_active = True
         else:
             self.is_active = False
 
     def apply_ir(self, ir):
         """Apply's IR to object"""
-        self.code_ir = ir if(isinstance(ir, str)) else \
-            jac_ast_to_ir(ir)
+        self.code_ir = ir if (isinstance(ir, str)) else jac_ast_to_ir(ir)
         self.code_sig = hashlib.md5(self.code_ir.encode()).hexdigest()
         jac_code.refresh(self)  # should disregard overloaded versions
 
-    def parse_jac(self, code, dir, start_rule='start'):
+    def parse_jac(self, code, dir, start_rule="start"):
         """Generate AST tree from Jac code text"""
-        tree = ast(jac_text=code, start_rule=start_rule, mod_name=self.name,
-                   mod_dir=dir)
+        tree = ast(
+            jac_text=code, start_rule=start_rule, mod_name=self.name, mod_dir=dir
+        )
         self.errors = tree._parse_errors
-        if(tree._parse_errors):
-            logger.error(str(f'{self.name}: Invalid syntax in Jac code!'))
+        if tree._parse_errors:
+            logger.error(str(f"{self.name}: Invalid syntax in Jac code!"))
             for i in tree._parse_errors:
                 logger.error(i)
             return None
@@ -91,16 +90,16 @@ class jac_code():
         """
         Parses Jac code and saves IR
         """
-        start_rule = 'start' if self.j_type == 'sentinel' else self.j_type
+        start_rule = "start" if self.j_type == "sentinel" else self.j_type
         tree = self.parse_jac(code, dir, start_rule=start_rule)
 
-        if(not tree):
+        if not tree:
             self.is_active = False
         else:
             self.apply_ir(tree)
 
-        if(not self.is_active):
-            logger.error(str(f'{self.name}: Code not registered'))
+        if not self.is_active:
+            logger.error(str(f"{self.name}: Code not registered"))
         return self.is_active
 
     def ir_dict(self):
