@@ -6,6 +6,7 @@ referenced through self.
 """
 from jaseci.utils.utils import logger
 from jaseci.actions.live_actions import live_actions, load_preconfig_actions
+
 # from jaseci.actions.find_action import find_action
 from jaseci.element.element import element
 
@@ -13,7 +14,7 @@ from jaseci.jac.jac_set import jac_set
 from jaseci.jac.machine.jac_scope import jac_scope
 
 
-class machine_state():
+class machine_state:
     """Shared interpreter class across both sentinels and walkers"""
 
     def __init__(self, parent_override=None, caller=None):
@@ -21,7 +22,7 @@ class machine_state():
         self.report_status = None
         self.runtime_errors = []
         self._parent_override = parent_override
-        if(not isinstance(self, element) and caller):
+        if not isinstance(self, element) and caller:
             self._m_id = caller._m_id
             self._h = caller._h
         self._scope_stack = [None]
@@ -34,7 +35,7 @@ class machine_state():
         self._cur_jac_ast = None
 
     def parent(self):
-        if(self._parent_override):
+        if self._parent_override:
             return self._parent_override
         else:
             return element.parent(self)
@@ -64,11 +65,9 @@ class machine_state():
 
     def get_arch_for(self, obj):
         """Returns the architype that matches object"""
-        ret = self.parent().arch_ids.get_obj_by_name(
-            name=obj.name, kind=obj.kind)
-        if(ret is None):
-            self.rt_error(
-                f"Unable to find architype for {obj.name}, {obj.kind}")
+        ret = self.parent().arch_ids.get_obj_by_name(name=obj.name, kind=obj.kind)
+        if ret is None:
+            self.rt_error(f"Unable to find architype for {obj.name}, {obj.kind}")
         return ret
 
     def obj_set_to_jac_set(self, obj_set):
@@ -96,7 +95,7 @@ class machine_state():
         ret = jac_set()
         for i in edge_set.obj_list():
             for j in node_set.obj_list():
-                if(i.jid in j.edge_ids):
+                if i.jid in j.edge_ids:
                     ret.add_obj(i)
                     break
         return ret
@@ -106,62 +105,63 @@ class machine_state():
         Takes reference to action attr, finds the built in function
         and returns new name used as hook by action class
         """
-        if(func_name not in live_actions.keys()):
+        if func_name not in live_actions.keys():
             load_preconfig_actions(self._h)
-        if(func_name not in live_actions.keys()):
+        if func_name not in live_actions.keys():
             self.rt_error(f"Builtin action not found - {func_name}", jac_ast)
         return func_name
 
     def jac_exception(self, e: Exception, jac_ast):
-        return {'type': type(e).__name__,
-                'mod': jac_ast.mod_name,
-                'msg': str(e),
-                'args': e.args,
-                'line': jac_ast.line,
-                'col': jac_ast.column}
+        return {
+            "type": type(e).__name__,
+            "mod": jac_ast.mod_name,
+            "msg": str(e),
+            "args": e.args,
+            "line": jac_ast.line,
+            "col": jac_ast.column,
+        }
 
     def rt_log_str(self, msg, jac_ast=None):
         """Generates string for screen output"""
-        if(jac_ast is None):
+        if jac_ast is None:
             jac_ast = self._cur_jac_ast
-        name = self.name if hasattr(self, 'name') else 'blank'
-        if(jac_ast):
-            msg = f'{jac_ast.mod_name}:{name} - line {jac_ast.line}, ' + \
-                f'col {jac_ast.column} - rule {jac_ast.name} - {msg}'
+        name = self.name if hasattr(self, "name") else "blank"
+        if jac_ast:
+            msg = (
+                f"{jac_ast.mod_name}:{name} - line {jac_ast.line}, "
+                + f"col {jac_ast.column} - rule {jac_ast.name} - {msg}"
+            )
         else:
-            msg = f'{msg}'
+            msg = f"{msg}"
         return msg
 
     def rt_warn(self, error, jac_ast=None):
         """Prints runtime error to screen"""
         error = self.rt_log_str(error, jac_ast)
-        logger.warning(
-            str(error)
-        )
+        logger.warning(str(error))
         self.runtime_errors.append(error)
 
     def rt_error(self, error, jac_ast=None):
         """Prints runtime error to screen"""
         error = self.rt_log_str(error, jac_ast)
-        logger.error(
-            str(error)
-        )
+        logger.error(str(error))
         self.runtime_errors.append(error)
 
     def rt_info(self, msg, jac_ast=None):
         """Prints runtime info to screen"""
-        logger.info(
-            str(self.rt_log_str(msg, jac_ast))
-        )
+        logger.info(str(self.rt_log_str(msg, jac_ast)))
 
     def rt_check_type(self, obj, typ, jac_ast=None):
         """Prints error if type mismatach"""
-        if(not isinstance(typ, list)):
+        if not isinstance(typ, list):
             typ = [typ]
         for i in typ:
-            if (isinstance(obj, i)):
+            if isinstance(obj, i):
                 return True
-        self.rt_error(f'Incompatible type for object '
-                      f'{obj} - {type(obj).__name__}, '
-                      f'expecting {typ}', jac_ast)
+        self.rt_error(
+            f"Incompatible type for object "
+            f"{obj} - {type(obj).__name__}, "
+            f"expecting {typ}",
+            jac_ast,
+        )
         return False
