@@ -21,28 +21,26 @@ class architype_tests(TestCaseHelper, TestCase):
         super().tearDown()
 
     def test_object_creation_basic_no_side_creation(self):
-        """
-        """
+        """ """
         mast = master(h=mem_hook())
         num_objs = len(mast._h.mem.keys())
         node1 = node(m_id=mast._m_id, h=mast._h)
         node2 = node(m_id=mast._m_id, h=mast._h, parent_id=node1.id)
         num_new = len(mast._h.mem.keys())
-        self.assertEqual(num_new, num_objs+2)
+        self.assertEqual(num_new, num_objs + 2)
 
         new_graph = graph(m_id=mast._m_id, h=mast._h)
         mast.graph_ids.add_obj(new_graph)
         num_new = len(mast._h.mem.keys())
-        self.assertEqual(num_new, num_objs+3)
+        self.assertEqual(num_new, num_objs + 3)
 
         new_graph.attach_outbound(node1)
         new_graph.attach_outbound(node2)
         num_new = len(mast._h.mem.keys())
-        self.assertEqual(num_new, num_objs+5)
+        self.assertEqual(num_new, num_objs + 5)
 
     def test_edge_removal_updates_nodes_edgelist(self):
-        """
-        """
+        """ """
         mast = master(h=mem_hook())
         node1 = node(m_id=mast._m_id, h=mast._h)
         node2 = node(m_id=mast._m_id, h=mast._h)
@@ -59,20 +57,20 @@ class architype_tests(TestCaseHelper, TestCase):
         Test that the destroy of sentinels clears owned objects
         """
         mast = master(h=mem_hook())
-        num_objs = len(mast._h.mem.keys())-len(mast._h.global_action_list)
+        num_objs = len(mast._h.mem.keys()) - len(mast._h.global_action_list)
         self.assertEqual(num_objs, 2)
         new_graph = graph(m_id=mast._m_id, h=mast._h)
         sent = sentinel(m_id=mast._m_id, h=mast._h)
         code = jtc.prog1
         mast.sentinel_ids.add_obj(sent)
         mast.graph_ids.add_obj(new_graph)
-        num_new = len(mast._h.mem.keys())-len(mast._h.global_action_list)
-        self.assertEqual(num_new, num_objs+2+3)
+        num_new = len(mast._h.mem.keys()) - len(mast._h.global_action_list)
+        self.assertEqual(num_new, num_objs + 2 + 3)
 
         sent.register_code(code)
-        num_objs = len(mast._h.mem.keys())-len(mast._h.global_action_list)
+        num_objs = len(mast._h.mem.keys()) - len(mast._h.global_action_list)
         sent.register_code(code)
-        new_num = len(mast._h.mem.keys())-len(mast._h.global_action_list)
+        new_num = len(mast._h.mem.keys()) - len(mast._h.global_action_list)
         self.assertEqual(num_objs, new_num)
 
     def test_json_blob_of_objects(self):
@@ -80,9 +78,9 @@ class architype_tests(TestCaseHelper, TestCase):
         Test saving object to json and back to python dict
         """
         for i in get_all_subclasses(element):
-            orig = i(m_id='anon', h=mem_hook())
+            orig = i(m_id="anon", h=mem_hook())
             blob1 = orig.json(detailed=True)
-            new = i(m_id='anon', h=mem_hook())
+            new = i(m_id="anon", h=mem_hook())
             self.assertNotEqual(orig.id, new.id)
             new.json_load(blob1)
             self.assertEqual(orig.id, new.id)
